@@ -16,17 +16,34 @@ class TestEnvStatus(enum.Enum):
 
 
 class TestEnvDef(BaseModel):
-    # Describes the setup used to run tests in
+    """
+    The TestEnv Definition determines the type of TestEnv by describes the setup used to run tests in
+
+    For example, there can be a separate TestEnvDefs for each of these:
+       - A setup with one CSS and 1 client
+       - A setup with one CSS and 2 client
+       - A setup with 3 CSS's and 4 client
+       - A setup with some other server software and a few clients
+
+    Each of these TestEnvDefs specifies how to setup this environment.
+
+    Currently, for each TestEnvDef.id, a specific ESpec to use is hardcoded. (This will be more flexible later)
+    """
+
     id: int
     name: str
     description: str
+
     # TODO especRepo: repo  # details about ESpec to use
     # fixed parameters for this environment. For example: clientCount, serverCpuCount,
     fixed_parameters: Dict[int, Union[str, int, bool]]  # parameterId to parameterValue
 
 
 class TestEnv(BaseModel):
-    # Describes a running test setup in which tests (= TestFragments) can be run
+    """
+    TestEnv describes a running test setup in which tests (= TestFragments) can be run
+    """
+
     id: int
     testenv_def_id: int  # this specifies if the TestEnv is jFed/slice based or something else
     slice_urn: Optional[str]  # optional during init and if not slice based
