@@ -139,7 +139,7 @@ async def call_external_command_async(
         for p in pending:
             p.cancel()
             proc.kill()
-        return -1
+        raise TimeoutError("command timed out")
     else:
         debug_log_handler(
             f"Command exited with exitcode {proc.returncode}",
